@@ -5,7 +5,7 @@
  * pgpool: a language independent connection pool server for PostgreSQL 
  * written by Tatsuo Ishii
  *
- * Copyright (c) 2003-2012	PgPool Global Development Group
+ * Copyright (c) 2003-2013	PgPool Global Development Group
  *
  * Permission to use, copy, modify, and distribute this software and
  * its documentation for any purpose and without fee is hereby
@@ -985,22 +985,15 @@ POOL_STATUS Bind(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *backend,
 	if (pool_send_and_wait(query_context, contents, len, 1, MASTER_NODE_ID, "B")
 		!= POOL_CONTINUE)
 	{
-		if (rewrite_msg != NULL)
-			/* free(rewrite_msg) */;
 		return POOL_END;
 	}
 
 	if (pool_send_and_wait(query_context, contents, len, -1, MASTER_NODE_ID, "B")
 		!= POOL_CONTINUE)
 	{
-		if (rewrite_msg != NULL)
-			/* free(rewrite_msg) */;
 		return POOL_END;
 	}
 
-	if (rewrite_msg != NULL)
-		/* free(rewrite_msg) */;
-
 	return POOL_CONTINUE;
 }
 
@@ -2464,8 +2457,9 @@ POOL_STATUS CopyDataRows(POOL_CONNECTION *frontend,
 						id = pool_get_id(info, p1);
 						pool_debug("CopyDataRow: copying id: %d", id);
 						free(p1);
-						if (!VALID_BACKEND(id))
+						if (id < 0 || !VALID_BACKEND(id))
 						{
+							pool_error("CopyDataRow: pool_get_id returns invalid id: %d", id);
 							exit(1);
 						}
 						if (pool_write(CONNECTION(backend, id), &kind, 1))
